pub fn frustum(
left: f32,
right: f32,
bottom: f32,
top: f32,
near: f32,
far: f32,
) -> Mat4Expand description
Creates a perspective projection from a frustum for use with Vulkan.
Expects a right-handed Y-up view space input. Outputs NDC with Z in [0, 1] and Y-down.
Panics
Will panic if near or far are less than or equal to zero when glam_assert is enabled.